#pragma once

namespace Misc
{
    namespace HelpViewer
    {
        void openHelp(const char* url);
    }
}
